.. highlight:: shell

============
Installation
============

From PyPI
---------

To install Taika, run this command in your terminal::

   pip install taika

You will get the last release.s

From source
-----------

The sources for Taika can be downloaded from the `GitLab repo`_.

Cloning using ``git``::

   git clone git://gitlab.com/hectormartinez/taika.git

Or downloading a tar::

   curl -OL https://gitlab.com/hectormartinez/taika/repository/master/archive.tar

Once you have a copy of the source, you can install it with::

   pip install .

.. _GitLab repo: https://gitlab.com/hectormartinez/taika
